<?php
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
namespace TencentCloud\Clb\V20180317\Models;
use TencentCloud\Common\AbstractModel;

/**
 * 监听器上绑定的后端服务的信息
 *
 * @method string getListenerId() 获取监听器 ID
 * @method void setListenerId(string $ListenerId) 设置监听器 ID
 * @method string getProtocol() 获取监听器的协议
 * @method void setProtocol(string $Protocol) 设置监听器的协议
 * @method integer getPort() 获取监听器的端口
 * @method void setPort(integer $Port) 设置监听器的端口
 * @method array getRules() 获取监听器下的规则信息（仅适用于HTTP/HTTPS监听器）
 * @method void setRules(array $Rules) 设置监听器下的规则信息（仅适用于HTTP/HTTPS监听器）
 * @method array getTargets() 获取监听器上绑定的后端服务列表（仅适用于TCP/UDP/TCP_SSL监听器）
 * @method void setTargets(array $Targets) 设置监听器上绑定的后端服务列表（仅适用于TCP/UDP/TCP_SSL监听器）
 * @method integer getEndPort() 获取若支持端口段，则为端口段结束端口；若不支持端口段，则为0
 * @method void setEndPort(integer $EndPort) 设置若支持端口段，则为端口段结束端口；若不支持端口段，则为0
 */
class ListenerBackend extends AbstractModel
{
    /**
     * @var string 监听器 ID
     */
    public $ListenerId;

    /**
     * @var string 监听器的协议
     */
    public $Protocol;

    /**
     * @var integer 监听器的端口
     */
    public $Port;

    /**
     * @var array 监听器下的规则信息（仅适用于HTTP/HTTPS监听器）
     */
    public $Rules;

    /**
     * @var array 监听器上绑定的后端服务列表（仅适用于TCP/UDP/TCP_SSL监听器）
     */
    public $Targets;

    /**
     * @var integer 若支持端口段，则为端口段结束端口；若不支持端口段，则为0
     */
    public $EndPort;

    /**
     * @param string $ListenerId 监听器 ID
     * @param string $Protocol 监听器的协议
     * @param integer $Port 监听器的端口
     * @param array $Rules 监听器下的规则信息（仅适用于HTTP/HTTPS监听器）
     * @param array $Targets 监听器上绑定的后端服务列表（仅适用于TCP/UDP/TCP_SSL监听器）
     * @param integer $EndPort 若支持端口段，则为端口段结束端口；若不支持端口段，则为0
     */
    function __construct()
    {

    }

    /**
     * For internal only. DO NOT USE IT.
     */
    public function deserialize($param)
    {
        if ($param === null) {
            return;
        }
        if (array_key_exists("ListenerId",$param) and $param["ListenerId"] !== null) {
            $this->ListenerId = $param["ListenerId"];
        }

        if (array_key_exists("Protocol",$param) and $param["Protocol"] !== null) {
            $this->Protocol = $param["Protocol"];
        }

        if (array_key_exists("Port",$param) and $param["Port"] !== null) {
            $this->Port = $param["Port"];
        }

        if (array_key_exists("Rules",$param) and $param["Rules"] !== null) {
            $this->Rules = [];
            foreach ($param["Rules"] as $key => $value){
                $obj = new RuleTargets();
                $obj->deserialize($value);
                array_push($this->Rules, $obj);
            }
        }

        if (array_key_exists("Targets",$param) and $param["Targets"] !== null) {
            $this->Targets = [];
            foreach ($param["Targets"] as $key => $value){
                $obj = new Backend();
                $obj->deserialize($value);
                array_push($this->Targets, $obj);
            }
        }

        if (array_key_exists("EndPort",$param) and $param["EndPort"] !== null) {
            $this->EndPort = $param["EndPort"];
        }
    }
}
