<?php
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
namespace TencentCloud\Faceid\V20180301\Models;
use TencentCloud\Common\AbstractModel;

/**
 * CheckIdCardInformation返回参数结构体
 *
 * @method float getSim() 获取相似度。
- 取值范围 [0.00, 100.00]。
- 推荐相似度大于等于70时可判断为同一人，可根据具体场景自行调整阈值（阈值70的误通过率为千分之一，阈值80的误通过率是万分之一）。
 * @method void setSim(float $Sim) 设置相似度。
- 取值范围 [0.00, 100.00]。
- 推荐相似度大于等于70时可判断为同一人，可根据具体场景自行调整阈值（阈值70的误通过率为千分之一，阈值80的误通过率是万分之一）。
 * @method string getResult() 获取业务错误码。- 成功情况返回Success。- 错误情况请参考下方错误码 列表中FailedOperation部分
 * @method void setResult(string $Result) 设置业务错误码。- 成功情况返回Success。- 错误情况请参考下方错误码 列表中FailedOperation部分
 * @method string getDescription() 获取业务结果描述。
 * @method void setDescription(string $Description) 设置业务结果描述。
 * @method string getName() 获取姓名。
 * @method void setName(string $Name) 设置姓名。
 * @method string getSex() 获取性别。
 * @method void setSex(string $Sex) 设置性别。
 * @method string getNation() 获取民族。
 * @method void setNation(string $Nation) 设置民族。
 * @method string getBirth() 获取出生日期。
 * @method void setBirth(string $Birth) 设置出生日期。
 * @method string getAddress() 获取地址。
 * @method void setAddress(string $Address) 设置地址。
 * @method string getIdNum() 获取身份证号。
 * @method void setIdNum(string $IdNum) 设置身份证号。
 * @method string getPortrait() 获取身份证头像照片的base64编码，如果抠图失败会拿整张身份证做比对并返回空。
 * @method void setPortrait(string $Portrait) 设置身份证头像照片的base64编码，如果抠图失败会拿整张身份证做比对并返回空。
 * @method string getWarnings() 获取告警信息。
- 当在Config中配置了告警信息会停止人像比对，Result返回错误（FailedOperation.OcrWarningOccurred）并有此告警信息。
- Code 告警码列表和释义：
'-9101'：身份证边框不完整告警。
'-9102'：身份证复印件告警。
'-9103'：身份证翻拍告警。
'-9105'：身份证框内遮挡告警。
'-9104'：临时身份证告警。
'-9106'：身份证 PS 告警（疑似存在PS痕迹）。
'-8001'：图片模糊告警。

- 多个会用“|” 隔开，如 "-9101|-9106|-9104"。
 * @method void setWarnings(string $Warnings) 设置告警信息。
- 当在Config中配置了告警信息会停止人像比对，Result返回错误（FailedOperation.OcrWarningOccurred）并有此告警信息。
- Code 告警码列表和释义：
'-9101'：身份证边框不完整告警。
'-9102'：身份证复印件告警。
'-9103'：身份证翻拍告警。
'-9105'：身份证框内遮挡告警。
'-9104'：临时身份证告警。
'-9106'：身份证 PS 告警（疑似存在PS痕迹）。
'-8001'：图片模糊告警。

- 多个会用“|” 隔开，如 "-9101|-9106|-9104"。
 * @method float getQuality() 获取图片质量分数。
- 当请求Config中配置图片模糊告警该参数才有意义。
- 取值范围（0～100），目前默认阈值是50分，低于50分会触发模糊告警。
 * @method void setQuality(float $Quality) 设置图片质量分数。
- 当请求Config中配置图片模糊告警该参数才有意义。
- 取值范围（0～100），目前默认阈值是50分，低于50分会触发模糊告警。
 * @method Encryption getEncryption() 获取敏感数据加密信息。
注意：此字段可能返回 null，表示取不到有效值。
 * @method void setEncryption(Encryption $Encryption) 设置敏感数据加密信息。
注意：此字段可能返回 null，表示取不到有效值。
 * @method string getEncryptedBody() 获取加密后的数据。
 * @method void setEncryptedBody(string $EncryptedBody) 设置加密后的数据。
 * @method string getRequestId() 获取唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
 * @method void setRequestId(string $RequestId) 设置唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
 */
class CheckIdCardInformationResponse extends AbstractModel
{
    /**
     * @var float 相似度。
- 取值范围 [0.00, 100.00]。
- 推荐相似度大于等于70时可判断为同一人，可根据具体场景自行调整阈值（阈值70的误通过率为千分之一，阈值80的误通过率是万分之一）。
     */
    public $Sim;

    /**
     * @var string 业务错误码。- 成功情况返回Success。- 错误情况请参考下方错误码 列表中FailedOperation部分
     */
    public $Result;

    /**
     * @var string 业务结果描述。
     */
    public $Description;

    /**
     * @var string 姓名。
     */
    public $Name;

    /**
     * @var string 性别。
     */
    public $Sex;

    /**
     * @var string 民族。
     */
    public $Nation;

    /**
     * @var string 出生日期。
     */
    public $Birth;

    /**
     * @var string 地址。
     */
    public $Address;

    /**
     * @var string 身份证号。
     */
    public $IdNum;

    /**
     * @var string 身份证头像照片的base64编码，如果抠图失败会拿整张身份证做比对并返回空。
     */
    public $Portrait;

    /**
     * @var string 告警信息。
- 当在Config中配置了告警信息会停止人像比对，Result返回错误（FailedOperation.OcrWarningOccurred）并有此告警信息。
- Code 告警码列表和释义：
'-9101'：身份证边框不完整告警。
'-9102'：身份证复印件告警。
'-9103'：身份证翻拍告警。
'-9105'：身份证框内遮挡告警。
'-9104'：临时身份证告警。
'-9106'：身份证 PS 告警（疑似存在PS痕迹）。
'-8001'：图片模糊告警。

- 多个会用“|” 隔开，如 "-9101|-9106|-9104"。
     */
    public $Warnings;

    /**
     * @var float 图片质量分数。
- 当请求Config中配置图片模糊告警该参数才有意义。
- 取值范围（0～100），目前默认阈值是50分，低于50分会触发模糊告警。
     */
    public $Quality;

    /**
     * @var Encryption 敏感数据加密信息。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public $Encryption;

    /**
     * @var string 加密后的数据。
     */
    public $EncryptedBody;

    /**
     * @var string 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public $RequestId;

    /**
     * @param float $Sim 相似度。
- 取值范围 [0.00, 100.00]。
- 推荐相似度大于等于70时可判断为同一人，可根据具体场景自行调整阈值（阈值70的误通过率为千分之一，阈值80的误通过率是万分之一）。
     * @param string $Result 业务错误码。- 成功情况返回Success。- 错误情况请参考下方错误码 列表中FailedOperation部分
     * @param string $Description 业务结果描述。
     * @param string $Name 姓名。
     * @param string $Sex 性别。
     * @param string $Nation 民族。
     * @param string $Birth 出生日期。
     * @param string $Address 地址。
     * @param string $IdNum 身份证号。
     * @param string $Portrait 身份证头像照片的base64编码，如果抠图失败会拿整张身份证做比对并返回空。
     * @param string $Warnings 告警信息。
- 当在Config中配置了告警信息会停止人像比对，Result返回错误（FailedOperation.OcrWarningOccurred）并有此告警信息。
- Code 告警码列表和释义：
'-9101'：身份证边框不完整告警。
'-9102'：身份证复印件告警。
'-9103'：身份证翻拍告警。
'-9105'：身份证框内遮挡告警。
'-9104'：临时身份证告警。
'-9106'：身份证 PS 告警（疑似存在PS痕迹）。
'-8001'：图片模糊告警。

- 多个会用“|” 隔开，如 "-9101|-9106|-9104"。
     * @param float $Quality 图片质量分数。
- 当请求Config中配置图片模糊告警该参数才有意义。
- 取值范围（0～100），目前默认阈值是50分，低于50分会触发模糊告警。
     * @param Encryption $Encryption 敏感数据加密信息。
注意：此字段可能返回 null，表示取不到有效值。
     * @param string $EncryptedBody 加密后的数据。
     * @param string $RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    function __construct()
    {

    }

    /**
     * For internal only. DO NOT USE IT.
     */
    public function deserialize($param)
    {
        if ($param === null) {
            return;
        }
        if (array_key_exists("Sim",$param) and $param["Sim"] !== null) {
            $this->Sim = $param["Sim"];
        }

        if (array_key_exists("Result",$param) and $param["Result"] !== null) {
            $this->Result = $param["Result"];
        }

        if (array_key_exists("Description",$param) and $param["Description"] !== null) {
            $this->Description = $param["Description"];
        }

        if (array_key_exists("Name",$param) and $param["Name"] !== null) {
            $this->Name = $param["Name"];
        }

        if (array_key_exists("Sex",$param) and $param["Sex"] !== null) {
            $this->Sex = $param["Sex"];
        }

        if (array_key_exists("Nation",$param) and $param["Nation"] !== null) {
            $this->Nation = $param["Nation"];
        }

        if (array_key_exists("Birth",$param) and $param["Birth"] !== null) {
            $this->Birth = $param["Birth"];
        }

        if (array_key_exists("Address",$param) and $param["Address"] !== null) {
            $this->Address = $param["Address"];
        }

        if (array_key_exists("IdNum",$param) and $param["IdNum"] !== null) {
            $this->IdNum = $param["IdNum"];
        }

        if (array_key_exists("Portrait",$param) and $param["Portrait"] !== null) {
            $this->Portrait = $param["Portrait"];
        }

        if (array_key_exists("Warnings",$param) and $param["Warnings"] !== null) {
            $this->Warnings = $param["Warnings"];
        }

        if (array_key_exists("Quality",$param) and $param["Quality"] !== null) {
            $this->Quality = $param["Quality"];
        }

        if (array_key_exists("Encryption",$param) and $param["Encryption"] !== null) {
            $this->Encryption = new Encryption();
            $this->Encryption->deserialize($param["Encryption"]);
        }

        if (array_key_exists("EncryptedBody",$param) and $param["EncryptedBody"] !== null) {
            $this->EncryptedBody = $param["EncryptedBody"];
        }

        if (array_key_exists("RequestId",$param) and $param["RequestId"] !== null) {
            $this->RequestId = $param["RequestId"];
        }
    }
}
