<?php
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
namespace TencentCloud\Gaap\V20180529\Models;
use TencentCloud\Common\AbstractModel;

/**
 * DescribeProxyStatistics请求参数结构体
 *
 * @method string getProxyId() 获取通道ID
 * @method void setProxyId(string $ProxyId) 设置通道ID
 * @method string getStartTime() 获取起始时间(2019-03-25 12:00:00)
 * @method void setStartTime(string $StartTime) 设置起始时间(2019-03-25 12:00:00)
 * @method string getEndTime() 获取结束时间(2019-03-25 12:00:00)
 * @method void setEndTime(string $EndTime) 设置结束时间(2019-03-25 12:00:00)
 * @method array getMetricNames() 获取统计指标名称列表，支持: 
入带宽:InBandwidth, 
出带宽:OutBandwidth, 
并发:Concurrent, 
入包量:InPackets, 
出包量:OutPackets, 
丢包率:PacketLoss, 
延迟:Latency，
HTTP请求量：HttpQPS, 
HTTP请求量利用率：HttpQPSPercent,
HTTPS请求量：HttpsQPS,
HTTPS请求量利用率：HttpsQPSPercent
 * @method void setMetricNames(array $MetricNames) 设置统计指标名称列表，支持: 
入带宽:InBandwidth, 
出带宽:OutBandwidth, 
并发:Concurrent, 
入包量:InPackets, 
出包量:OutPackets, 
丢包率:PacketLoss, 
延迟:Latency，
HTTP请求量：HttpQPS, 
HTTP请求量利用率：HttpQPSPercent,
HTTPS请求量：HttpsQPS,
HTTPS请求量利用率：HttpsQPSPercent
 * @method integer getGranularity() 获取监控粒度，目前支持60，300，3600，86400，单位：秒。
当时间范围不超过3天，支持最小粒度60秒；
当时间范围不超过7天，支持最小粒度300秒；
当时间范围不超过30天，支持最小粒度3600秒。
 * @method void setGranularity(integer $Granularity) 设置监控粒度，目前支持60，300，3600，86400，单位：秒。
当时间范围不超过3天，支持最小粒度60秒；
当时间范围不超过7天，支持最小粒度300秒；
当时间范围不超过30天，支持最小粒度3600秒。
 * @method string getIsp() 获取运营商（通道为三网通道时有效），支持CMCC，CUCC，CTCC，传空值或不传则合并三个运营商数据
 * @method void setIsp(string $Isp) 设置运营商（通道为三网通道时有效），支持CMCC，CUCC，CTCC，传空值或不传则合并三个运营商数据
 */
class DescribeProxyStatisticsRequest extends AbstractModel
{
    /**
     * @var string 通道ID
     */
    public $ProxyId;

    /**
     * @var string 起始时间(2019-03-25 12:00:00)
     */
    public $StartTime;

    /**
     * @var string 结束时间(2019-03-25 12:00:00)
     */
    public $EndTime;

    /**
     * @var array 统计指标名称列表，支持: 
入带宽:InBandwidth, 
出带宽:OutBandwidth, 
并发:Concurrent, 
入包量:InPackets, 
出包量:OutPackets, 
丢包率:PacketLoss, 
延迟:Latency，
HTTP请求量：HttpQPS, 
HTTP请求量利用率：HttpQPSPercent,
HTTPS请求量：HttpsQPS,
HTTPS请求量利用率：HttpsQPSPercent
     */
    public $MetricNames;

    /**
     * @var integer 监控粒度，目前支持60，300，3600，86400，单位：秒。
当时间范围不超过3天，支持最小粒度60秒；
当时间范围不超过7天，支持最小粒度300秒；
当时间范围不超过30天，支持最小粒度3600秒。
     */
    public $Granularity;

    /**
     * @var string 运营商（通道为三网通道时有效），支持CMCC，CUCC，CTCC，传空值或不传则合并三个运营商数据
     */
    public $Isp;

    /**
     * @param string $ProxyId 通道ID
     * @param string $StartTime 起始时间(2019-03-25 12:00:00)
     * @param string $EndTime 结束时间(2019-03-25 12:00:00)
     * @param array $MetricNames 统计指标名称列表，支持: 
入带宽:InBandwidth, 
出带宽:OutBandwidth, 
并发:Concurrent, 
入包量:InPackets, 
出包量:OutPackets, 
丢包率:PacketLoss, 
延迟:Latency，
HTTP请求量：HttpQPS, 
HTTP请求量利用率：HttpQPSPercent,
HTTPS请求量：HttpsQPS,
HTTPS请求量利用率：HttpsQPSPercent
     * @param integer $Granularity 监控粒度，目前支持60，300，3600，86400，单位：秒。
当时间范围不超过3天，支持最小粒度60秒；
当时间范围不超过7天，支持最小粒度300秒；
当时间范围不超过30天，支持最小粒度3600秒。
     * @param string $Isp 运营商（通道为三网通道时有效），支持CMCC，CUCC，CTCC，传空值或不传则合并三个运营商数据
     */
    function __construct()
    {

    }

    /**
     * For internal only. DO NOT USE IT.
     */
    public function deserialize($param)
    {
        if ($param === null) {
            return;
        }
        if (array_key_exists("ProxyId",$param) and $param["ProxyId"] !== null) {
            $this->ProxyId = $param["ProxyId"];
        }

        if (array_key_exists("StartTime",$param) and $param["StartTime"] !== null) {
            $this->StartTime = $param["StartTime"];
        }

        if (array_key_exists("EndTime",$param) and $param["EndTime"] !== null) {
            $this->EndTime = $param["EndTime"];
        }

        if (array_key_exists("MetricNames",$param) and $param["MetricNames"] !== null) {
            $this->MetricNames = $param["MetricNames"];
        }

        if (array_key_exists("Granularity",$param) and $param["Granularity"] !== null) {
            $this->Granularity = $param["Granularity"];
        }

        if (array_key_exists("Isp",$param) and $param["Isp"] !== null) {
            $this->Isp = $param["Isp"];
        }
    }
}
