<?php
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
namespace TencentCloud\Iai\V20200303\Models;
use TencentCloud\Common\AbstractModel;

/**
 * CreatePerson返回参数结构体
 *
 * @method string getFaceId() 获取人脸图片唯一标识。
 * @method void setFaceId(string $FaceId) 设置人脸图片唯一标识。
 * @method FaceRect getFaceRect() 获取检测出的人脸框的位置。
注意：此字段可能返回 null，表示取不到有效值。
 * @method void setFaceRect(FaceRect $FaceRect) 设置检测出的人脸框的位置。
注意：此字段可能返回 null，表示取不到有效值。
 * @method string getSimilarPersonId() 获取疑似同一人的PersonId。 
- 当 UniquePersonControl 参数不为0且人员库中有疑似的同一人，此参数才有意义。
 * @method void setSimilarPersonId(string $SimilarPersonId) 设置疑似同一人的PersonId。 
- 当 UniquePersonControl 参数不为0且人员库中有疑似的同一人，此参数才有意义。
 * @method string getFaceModelVersion() 获取人脸识别所用的算法模型版本。
 * @method void setFaceModelVersion(string $FaceModelVersion) 设置人脸识别所用的算法模型版本。
 * @method string getRequestId() 获取唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
 * @method void setRequestId(string $RequestId) 设置唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
 */
class CreatePersonResponse extends AbstractModel
{
    /**
     * @var string 人脸图片唯一标识。
     */
    public $FaceId;

    /**
     * @var FaceRect 检测出的人脸框的位置。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public $FaceRect;

    /**
     * @var string 疑似同一人的PersonId。 
- 当 UniquePersonControl 参数不为0且人员库中有疑似的同一人，此参数才有意义。
     */
    public $SimilarPersonId;

    /**
     * @var string 人脸识别所用的算法模型版本。
     */
    public $FaceModelVersion;

    /**
     * @var string 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public $RequestId;

    /**
     * @param string $FaceId 人脸图片唯一标识。
     * @param FaceRect $FaceRect 检测出的人脸框的位置。
注意：此字段可能返回 null，表示取不到有效值。
     * @param string $SimilarPersonId 疑似同一人的PersonId。 
- 当 UniquePersonControl 参数不为0且人员库中有疑似的同一人，此参数才有意义。
     * @param string $FaceModelVersion 人脸识别所用的算法模型版本。
     * @param string $RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    function __construct()
    {

    }

    /**
     * For internal only. DO NOT USE IT.
     */
    public function deserialize($param)
    {
        if ($param === null) {
            return;
        }
        if (array_key_exists("FaceId",$param) and $param["FaceId"] !== null) {
            $this->FaceId = $param["FaceId"];
        }

        if (array_key_exists("FaceRect",$param) and $param["FaceRect"] !== null) {
            $this->FaceRect = new FaceRect();
            $this->FaceRect->deserialize($param["FaceRect"]);
        }

        if (array_key_exists("SimilarPersonId",$param) and $param["SimilarPersonId"] !== null) {
            $this->SimilarPersonId = $param["SimilarPersonId"];
        }

        if (array_key_exists("FaceModelVersion",$param) and $param["FaceModelVersion"] !== null) {
            $this->FaceModelVersion = $param["FaceModelVersion"];
        }

        if (array_key_exists("RequestId",$param) and $param["RequestId"] !== null) {
            $this->RequestId = $param["RequestId"];
        }
    }
}
