<?php
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
namespace TencentCloud\Iai\V20200303\Models;
use TencentCloud\Common\AbstractModel;

/**
 * 人脸质量信息，包含质量分（score）、模糊分（sharpness）、光照分（brightness）、遮挡分（completeness）。只有当NeedFaceDetection设为1时才返回有效信息。
 *
 * @method integer getScore() 获取质量分。
- 取值范围：[0,100]，综合评价图像质量是否适合人脸识别，分数越高质量越好。 
- 正常情况，只需要使用Score作为质量分总体的判断标准即可。Sharpness、Brightness、Completeness等细项分仅供参考。
- 参考范围：[0,40]较差，[40,60] 一般，[60,80]较好，[80,100]很好。 
- 建议：人脸入库选取70以上的图片。
注意：此字段可能返回 null，表示取不到有效值。
 * @method void setScore(integer $Score) 设置质量分。
- 取值范围：[0,100]，综合评价图像质量是否适合人脸识别，分数越高质量越好。 
- 正常情况，只需要使用Score作为质量分总体的判断标准即可。Sharpness、Brightness、Completeness等细项分仅供参考。
- 参考范围：[0,40]较差，[40,60] 一般，[60,80]较好，[80,100]很好。 
- 建议：人脸入库选取70以上的图片。
注意：此字段可能返回 null，表示取不到有效值。
 * @method integer getSharpness() 获取清晰分。
- 取值范围：[0,100]，评价图片清晰程度，分数越高越清晰。 
- 参考范围：[0,40]特别模糊，[40,60]模糊，[60,80]一般，[80,100]清晰。 
- 建议：人脸入库选取80以上的图片。
注意：此字段可能返回 null，表示取不到有效值。
 * @method void setSharpness(integer $Sharpness) 设置清晰分。
- 取值范围：[0,100]，评价图片清晰程度，分数越高越清晰。 
- 参考范围：[0,40]特别模糊，[40,60]模糊，[60,80]一般，[80,100]清晰。 
- 建议：人脸入库选取80以上的图片。
注意：此字段可能返回 null，表示取不到有效值。
 * @method integer getBrightness() 获取光照分。
- 取值范围：[0,100]，评价图片光照程度，分数越高越亮。 
- 参考范围： [0,30]偏暗，[30,70]光照正常，[70,100]偏亮。 
- 建议：人脸入库选取[30,70]的图片。
注意：此字段可能返回 null，表示取不到有效值。
 * @method void setBrightness(integer $Brightness) 设置光照分。
- 取值范围：[0,100]，评价图片光照程度，分数越高越亮。 
- 参考范围： [0,30]偏暗，[30,70]光照正常，[70,100]偏亮。 
- 建议：人脸入库选取[30,70]的图片。
注意：此字段可能返回 null，表示取不到有效值。
 * @method FaceQualityCompleteness getCompleteness() 获取五官遮挡分，评价眉毛（Eyebrow）、眼睛（Eye）、鼻子（Nose）、脸颊（Cheek）、嘴巴（Mouth）、下巴（Chin）的被遮挡程度。
注意：此字段可能返回 null，表示取不到有效值。
 * @method void setCompleteness(FaceQualityCompleteness $Completeness) 设置五官遮挡分，评价眉毛（Eyebrow）、眼睛（Eye）、鼻子（Nose）、脸颊（Cheek）、嘴巴（Mouth）、下巴（Chin）的被遮挡程度。
注意：此字段可能返回 null，表示取不到有效值。
 */
class FaceQualityInfo extends AbstractModel
{
    /**
     * @var integer 质量分。
- 取值范围：[0,100]，综合评价图像质量是否适合人脸识别，分数越高质量越好。 
- 正常情况，只需要使用Score作为质量分总体的判断标准即可。Sharpness、Brightness、Completeness等细项分仅供参考。
- 参考范围：[0,40]较差，[40,60] 一般，[60,80]较好，[80,100]很好。 
- 建议：人脸入库选取70以上的图片。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public $Score;

    /**
     * @var integer 清晰分。
- 取值范围：[0,100]，评价图片清晰程度，分数越高越清晰。 
- 参考范围：[0,40]特别模糊，[40,60]模糊，[60,80]一般，[80,100]清晰。 
- 建议：人脸入库选取80以上的图片。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public $Sharpness;

    /**
     * @var integer 光照分。
- 取值范围：[0,100]，评价图片光照程度，分数越高越亮。 
- 参考范围： [0,30]偏暗，[30,70]光照正常，[70,100]偏亮。 
- 建议：人脸入库选取[30,70]的图片。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public $Brightness;

    /**
     * @var FaceQualityCompleteness 五官遮挡分，评价眉毛（Eyebrow）、眼睛（Eye）、鼻子（Nose）、脸颊（Cheek）、嘴巴（Mouth）、下巴（Chin）的被遮挡程度。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public $Completeness;

    /**
     * @param integer $Score 质量分。
- 取值范围：[0,100]，综合评价图像质量是否适合人脸识别，分数越高质量越好。 
- 正常情况，只需要使用Score作为质量分总体的判断标准即可。Sharpness、Brightness、Completeness等细项分仅供参考。
- 参考范围：[0,40]较差，[40,60] 一般，[60,80]较好，[80,100]很好。 
- 建议：人脸入库选取70以上的图片。
注意：此字段可能返回 null，表示取不到有效值。
     * @param integer $Sharpness 清晰分。
- 取值范围：[0,100]，评价图片清晰程度，分数越高越清晰。 
- 参考范围：[0,40]特别模糊，[40,60]模糊，[60,80]一般，[80,100]清晰。 
- 建议：人脸入库选取80以上的图片。
注意：此字段可能返回 null，表示取不到有效值。
     * @param integer $Brightness 光照分。
- 取值范围：[0,100]，评价图片光照程度，分数越高越亮。 
- 参考范围： [0,30]偏暗，[30,70]光照正常，[70,100]偏亮。 
- 建议：人脸入库选取[30,70]的图片。
注意：此字段可能返回 null，表示取不到有效值。
     * @param FaceQualityCompleteness $Completeness 五官遮挡分，评价眉毛（Eyebrow）、眼睛（Eye）、鼻子（Nose）、脸颊（Cheek）、嘴巴（Mouth）、下巴（Chin）的被遮挡程度。
注意：此字段可能返回 null，表示取不到有效值。
     */
    function __construct()
    {

    }

    /**
     * For internal only. DO NOT USE IT.
     */
    public function deserialize($param)
    {
        if ($param === null) {
            return;
        }
        if (array_key_exists("Score",$param) and $param["Score"] !== null) {
            $this->Score = $param["Score"];
        }

        if (array_key_exists("Sharpness",$param) and $param["Sharpness"] !== null) {
            $this->Sharpness = $param["Sharpness"];
        }

        if (array_key_exists("Brightness",$param) and $param["Brightness"] !== null) {
            $this->Brightness = $param["Brightness"];
        }

        if (array_key_exists("Completeness",$param) and $param["Completeness"] !== null) {
            $this->Completeness = new FaceQualityCompleteness();
            $this->Completeness->deserialize($param["Completeness"]);
        }
    }
}
