<?php
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
namespace TencentCloud\Smh\V20210712\Models;
use TencentCloud\Common\AbstractModel;

/**
 * 官方云盘实例信息
 *
 * @method string getInstanceId() 获取实例 ID
 * @method void setInstanceId(string $InstanceId) 设置实例 ID
 * @method string getDomain() 获取专属域名。如果实例无专属域名，则该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
 * @method void setDomain(string $Domain) 设置专属域名。如果实例无专属域名，则该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
 * @method string getEffectiveTime() 获取生效时间
 * @method void setEffectiveTime(string $EffectiveTime) 设置生效时间
 * @method string getExpireTime() 获取过期时间。如果为按量计费或永久有效实例，该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
 * @method void setExpireTime(string $ExpireTime) 设置过期时间。如果为按量计费或永久有效实例，该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
 * @method integer getUserLimit() 获取用户数量。如果为按量计费或不限制用户数量实例，该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
 * @method void setUserLimit(integer $UserLimit) 设置用户数量。如果为按量计费或不限制用户数量实例，该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
 * @method string getStorageLimit() 获取存储容量，单位为 Bytes，由于数字类型精度限制，该字段为 String 类型。如果为按量计费或不限制存储容量实例，该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
 * @method void setStorageLimit(string $StorageLimit) 设置存储容量，单位为 Bytes，由于数字类型精度限制，该字段为 String 类型。如果为按量计费或不限制存储容量实例，该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
 * @method integer getStorageLimitGB() 获取存储容量，单位为 GB。如果为按量计费或不限制存储容量实例，该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
 * @method void setStorageLimitGB(integer $StorageLimitGB) 设置存储容量，单位为 GB。如果为按量计费或不限制存储容量实例，该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
 * @method boolean getIsolated() 获取是否过期隔离
 * @method void setIsolated(boolean $Isolated) 设置是否过期隔离
 * @method integer getAutoRenew() 获取续费标识。0：手动续费；1：自动续费；2：到期不续。
 * @method void setAutoRenew(integer $AutoRenew) 设置续费标识。0：手动续费；1：自动续费；2：到期不续。
 * @method string getSuperAdminAccount() 获取超级管理员账号，如果未选择查询实例绑定的超级管理员账号或当前实例未绑定超级管理员账号，则该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
 * @method void setSuperAdminAccount(string $SuperAdminAccount) 设置超级管理员账号，如果未选择查询实例绑定的超级管理员账号或当前实例未绑定超级管理员账号，则该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
 * @method string getBucket() 获取自选桶模式下，展示存储桶使用
 * @method void setBucket(string $Bucket) 设置自选桶模式下，展示存储桶使用
 * @method string getLogBucket() 获取自选桶模式下，展示日志桶使用
注意：此字段可能返回 null，表示取不到有效值。
 * @method void setLogBucket(string $LogBucket) 设置自选桶模式下，展示日志桶使用
注意：此字段可能返回 null，表示取不到有效值。
 */
class Instance extends AbstractModel
{
    /**
     * @var string 实例 ID
     */
    public $InstanceId;

    /**
     * @var string 专属域名。如果实例无专属域名，则该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public $Domain;

    /**
     * @var string 生效时间
     */
    public $EffectiveTime;

    /**
     * @var string 过期时间。如果为按量计费或永久有效实例，该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public $ExpireTime;

    /**
     * @var integer 用户数量。如果为按量计费或不限制用户数量实例，该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public $UserLimit;

    /**
     * @var string 存储容量，单位为 Bytes，由于数字类型精度限制，该字段为 String 类型。如果为按量计费或不限制存储容量实例，该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public $StorageLimit;

    /**
     * @var integer 存储容量，单位为 GB。如果为按量计费或不限制存储容量实例，该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public $StorageLimitGB;

    /**
     * @var boolean 是否过期隔离
     */
    public $Isolated;

    /**
     * @var integer 续费标识。0：手动续费；1：自动续费；2：到期不续。
     */
    public $AutoRenew;

    /**
     * @var string 超级管理员账号，如果未选择查询实例绑定的超级管理员账号或当前实例未绑定超级管理员账号，则该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public $SuperAdminAccount;

    /**
     * @var string 自选桶模式下，展示存储桶使用
     */
    public $Bucket;

    /**
     * @var string 自选桶模式下，展示日志桶使用
注意：此字段可能返回 null，表示取不到有效值。
     */
    public $LogBucket;

    /**
     * @param string $InstanceId 实例 ID
     * @param string $Domain 专属域名。如果实例无专属域名，则该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
     * @param string $EffectiveTime 生效时间
     * @param string $ExpireTime 过期时间。如果为按量计费或永久有效实例，该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
     * @param integer $UserLimit 用户数量。如果为按量计费或不限制用户数量实例，该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
     * @param string $StorageLimit 存储容量，单位为 Bytes，由于数字类型精度限制，该字段为 String 类型。如果为按量计费或不限制存储容量实例，该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
     * @param integer $StorageLimitGB 存储容量，单位为 GB。如果为按量计费或不限制存储容量实例，该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
     * @param boolean $Isolated 是否过期隔离
     * @param integer $AutoRenew 续费标识。0：手动续费；1：自动续费；2：到期不续。
     * @param string $SuperAdminAccount 超级管理员账号，如果未选择查询实例绑定的超级管理员账号或当前实例未绑定超级管理员账号，则该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
     * @param string $Bucket 自选桶模式下，展示存储桶使用
     * @param string $LogBucket 自选桶模式下，展示日志桶使用
注意：此字段可能返回 null，表示取不到有效值。
     */
    function __construct()
    {

    }

    /**
     * For internal only. DO NOT USE IT.
     */
    public function deserialize($param)
    {
        if ($param === null) {
            return;
        }
        if (array_key_exists("InstanceId",$param) and $param["InstanceId"] !== null) {
            $this->InstanceId = $param["InstanceId"];
        }

        if (array_key_exists("Domain",$param) and $param["Domain"] !== null) {
            $this->Domain = $param["Domain"];
        }

        if (array_key_exists("EffectiveTime",$param) and $param["EffectiveTime"] !== null) {
            $this->EffectiveTime = $param["EffectiveTime"];
        }

        if (array_key_exists("ExpireTime",$param) and $param["ExpireTime"] !== null) {
            $this->ExpireTime = $param["ExpireTime"];
        }

        if (array_key_exists("UserLimit",$param) and $param["UserLimit"] !== null) {
            $this->UserLimit = $param["UserLimit"];
        }

        if (array_key_exists("StorageLimit",$param) and $param["StorageLimit"] !== null) {
            $this->StorageLimit = $param["StorageLimit"];
        }

        if (array_key_exists("StorageLimitGB",$param) and $param["StorageLimitGB"] !== null) {
            $this->StorageLimitGB = $param["StorageLimitGB"];
        }

        if (array_key_exists("Isolated",$param) and $param["Isolated"] !== null) {
            $this->Isolated = $param["Isolated"];
        }

        if (array_key_exists("AutoRenew",$param) and $param["AutoRenew"] !== null) {
            $this->AutoRenew = $param["AutoRenew"];
        }

        if (array_key_exists("SuperAdminAccount",$param) and $param["SuperAdminAccount"] !== null) {
            $this->SuperAdminAccount = $param["SuperAdminAccount"];
        }

        if (array_key_exists("Bucket",$param) and $param["Bucket"] !== null) {
            $this->Bucket = $param["Bucket"];
        }

        if (array_key_exists("LogBucket",$param) and $param["LogBucket"] !== null) {
            $this->LogBucket = $param["LogBucket"];
        }
    }
}
