<?php
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
namespace TencentCloud\Tione\V20211111\Models;
use TencentCloud\Common\AbstractModel;

/**
 * 资源配置
 *
 * @method string getRole() 获取角色，eg：PS、WORKER、DRIVER、EXECUTOR
 * @method void setRole(string $Role) 设置角色，eg：PS、WORKER、DRIVER、EXECUTOR
 * @method integer getCpu() 获取cpu核数，使用资源组时需配置。单位：1/1000，即1000=1核
 * @method void setCpu(integer $Cpu) 设置cpu核数，使用资源组时需配置。单位：1/1000，即1000=1核
 * @method integer getMemory() 获取内存，使用资源组时需配置。单位为MB
 * @method void setMemory(integer $Memory) 设置内存，使用资源组时需配置。单位为MB
 * @method string getGpuType() 获取gpu卡类型，使用资源组时需配置
 * @method void setGpuType(string $GpuType) 设置gpu卡类型，使用资源组时需配置
 * @method integer getGpu() 获取gpu卡数，使用资源组时需配置。单位：1/100，即100=1卡
 * @method void setGpu(integer $Gpu) 设置gpu卡数，使用资源组时需配置。单位：1/100，即100=1卡
 * @method string getInstanceType() 获取算力规格ID
计算规格 (for后付费)，可选值如下：
TI.S.LARGE.POST: 4C8G 
TI.S.2XLARGE16.POST:  8C16G 
TI.S.2XLARGE32.POST:  8C32G 
TI.S.4XLARGE32.POST:  16C32G
TI.S.4XLARGE64.POST:  16C64G
TI.S.6XLARGE48.POST:  24C48G
TI.S.6XLARGE96.POST:  24C96G
TI.S.8XLARGE64.POST:  32C64G
TI.S.8XLARGE128.POST : 32C128G
TI.GN10.2XLARGE40.POST: 8C40G V100*1 
TI.GN10.5XLARGE80.POST:  18C80G V100*2 
TI.GN10.10XLARGE160.POST :  32C160G V100*4
TI.GN10.20XLARGE320.POST :  72C320G V100*8
TI.GN7.8XLARGE128.POST: 32C128G T4*1 
TI.GN7.10XLARGE160.POST: 40C160G T4*2 
TI.GN7.20XLARGE320.POST: 80C32
 * @method void setInstanceType(string $InstanceType) 设置算力规格ID
计算规格 (for后付费)，可选值如下：
TI.S.LARGE.POST: 4C8G 
TI.S.2XLARGE16.POST:  8C16G 
TI.S.2XLARGE32.POST:  8C32G 
TI.S.4XLARGE32.POST:  16C32G
TI.S.4XLARGE64.POST:  16C64G
TI.S.6XLARGE48.POST:  24C48G
TI.S.6XLARGE96.POST:  24C96G
TI.S.8XLARGE64.POST:  32C64G
TI.S.8XLARGE128.POST : 32C128G
TI.GN10.2XLARGE40.POST: 8C40G V100*1 
TI.GN10.5XLARGE80.POST:  18C80G V100*2 
TI.GN10.10XLARGE160.POST :  32C160G V100*4
TI.GN10.20XLARGE320.POST :  72C320G V100*8
TI.GN7.8XLARGE128.POST: 32C128G T4*1 
TI.GN7.10XLARGE160.POST: 40C160G T4*2 
TI.GN7.20XLARGE320.POST: 80C32
 * @method integer getInstanceNum() 获取计算节点数
 * @method void setInstanceNum(integer $InstanceNum) 设置计算节点数
 * @method string getInstanceTypeAlias() 获取算力规格名称
计算规格 (for后付费)，可选值如下：
4C8G 
8C16G 
8C32G 
16C32G
6C64G
24C48G
24C96G
32C64G
32C128G
8C40G V100*1 
8C80G V100*2 
32C160G V100*4
72C320G V100*8
32C128G T4*1 
40C160G T4*2 
80C32
 * @method void setInstanceTypeAlias(string $InstanceTypeAlias) 设置算力规格名称
计算规格 (for后付费)，可选值如下：
4C8G 
8C16G 
8C32G 
16C32G
6C64G
24C48G
24C96G
32C64G
32C128G
8C40G V100*1 
8C80G V100*2 
32C160G V100*4
72C320G V100*8
32C128G T4*1 
40C160G T4*2 
80C32
 * @method RDMAConfig getRDMAConfig() 获取RDMA配置
注意：此字段可能返回 null，表示取不到有效值。
 * @method void setRDMAConfig(RDMAConfig $RDMAConfig) 设置RDMA配置
注意：此字段可能返回 null，表示取不到有效值。
 */
class ResourceConfigInfo extends AbstractModel
{
    /**
     * @var string 角色，eg：PS、WORKER、DRIVER、EXECUTOR
     */
    public $Role;

    /**
     * @var integer cpu核数，使用资源组时需配置。单位：1/1000，即1000=1核
     */
    public $Cpu;

    /**
     * @var integer 内存，使用资源组时需配置。单位为MB
     */
    public $Memory;

    /**
     * @var string gpu卡类型，使用资源组时需配置
     */
    public $GpuType;

    /**
     * @var integer gpu卡数，使用资源组时需配置。单位：1/100，即100=1卡
     */
    public $Gpu;

    /**
     * @var string 算力规格ID
计算规格 (for后付费)，可选值如下：
TI.S.LARGE.POST: 4C8G 
TI.S.2XLARGE16.POST:  8C16G 
TI.S.2XLARGE32.POST:  8C32G 
TI.S.4XLARGE32.POST:  16C32G
TI.S.4XLARGE64.POST:  16C64G
TI.S.6XLARGE48.POST:  24C48G
TI.S.6XLARGE96.POST:  24C96G
TI.S.8XLARGE64.POST:  32C64G
TI.S.8XLARGE128.POST : 32C128G
TI.GN10.2XLARGE40.POST: 8C40G V100*1 
TI.GN10.5XLARGE80.POST:  18C80G V100*2 
TI.GN10.10XLARGE160.POST :  32C160G V100*4
TI.GN10.20XLARGE320.POST :  72C320G V100*8
TI.GN7.8XLARGE128.POST: 32C128G T4*1 
TI.GN7.10XLARGE160.POST: 40C160G T4*2 
TI.GN7.20XLARGE320.POST: 80C32
     */
    public $InstanceType;

    /**
     * @var integer 计算节点数
     */
    public $InstanceNum;

    /**
     * @var string 算力规格名称
计算规格 (for后付费)，可选值如下：
4C8G 
8C16G 
8C32G 
16C32G
6C64G
24C48G
24C96G
32C64G
32C128G
8C40G V100*1 
8C80G V100*2 
32C160G V100*4
72C320G V100*8
32C128G T4*1 
40C160G T4*2 
80C32
     */
    public $InstanceTypeAlias;

    /**
     * @var RDMAConfig RDMA配置
注意：此字段可能返回 null，表示取不到有效值。
     */
    public $RDMAConfig;

    /**
     * @param string $Role 角色，eg：PS、WORKER、DRIVER、EXECUTOR
     * @param integer $Cpu cpu核数，使用资源组时需配置。单位：1/1000，即1000=1核
     * @param integer $Memory 内存，使用资源组时需配置。单位为MB
     * @param string $GpuType gpu卡类型，使用资源组时需配置
     * @param integer $Gpu gpu卡数，使用资源组时需配置。单位：1/100，即100=1卡
     * @param string $InstanceType 算力规格ID
计算规格 (for后付费)，可选值如下：
TI.S.LARGE.POST: 4C8G 
TI.S.2XLARGE16.POST:  8C16G 
TI.S.2XLARGE32.POST:  8C32G 
TI.S.4XLARGE32.POST:  16C32G
TI.S.4XLARGE64.POST:  16C64G
TI.S.6XLARGE48.POST:  24C48G
TI.S.6XLARGE96.POST:  24C96G
TI.S.8XLARGE64.POST:  32C64G
TI.S.8XLARGE128.POST : 32C128G
TI.GN10.2XLARGE40.POST: 8C40G V100*1 
TI.GN10.5XLARGE80.POST:  18C80G V100*2 
TI.GN10.10XLARGE160.POST :  32C160G V100*4
TI.GN10.20XLARGE320.POST :  72C320G V100*8
TI.GN7.8XLARGE128.POST: 32C128G T4*1 
TI.GN7.10XLARGE160.POST: 40C160G T4*2 
TI.GN7.20XLARGE320.POST: 80C32
     * @param integer $InstanceNum 计算节点数
     * @param string $InstanceTypeAlias 算力规格名称
计算规格 (for后付费)，可选值如下：
4C8G 
8C16G 
8C32G 
16C32G
6C64G
24C48G
24C96G
32C64G
32C128G
8C40G V100*1 
8C80G V100*2 
32C160G V100*4
72C320G V100*8
32C128G T4*1 
40C160G T4*2 
80C32
     * @param RDMAConfig $RDMAConfig RDMA配置
注意：此字段可能返回 null，表示取不到有效值。
     */
    function __construct()
    {

    }

    /**
     * For internal only. DO NOT USE IT.
     */
    public function deserialize($param)
    {
        if ($param === null) {
            return;
        }
        if (array_key_exists("Role",$param) and $param["Role"] !== null) {
            $this->Role = $param["Role"];
        }

        if (array_key_exists("Cpu",$param) and $param["Cpu"] !== null) {
            $this->Cpu = $param["Cpu"];
        }

        if (array_key_exists("Memory",$param) and $param["Memory"] !== null) {
            $this->Memory = $param["Memory"];
        }

        if (array_key_exists("GpuType",$param) and $param["GpuType"] !== null) {
            $this->GpuType = $param["GpuType"];
        }

        if (array_key_exists("Gpu",$param) and $param["Gpu"] !== null) {
            $this->Gpu = $param["Gpu"];
        }

        if (array_key_exists("InstanceType",$param) and $param["InstanceType"] !== null) {
            $this->InstanceType = $param["InstanceType"];
        }

        if (array_key_exists("InstanceNum",$param) and $param["InstanceNum"] !== null) {
            $this->InstanceNum = $param["InstanceNum"];
        }

        if (array_key_exists("InstanceTypeAlias",$param) and $param["InstanceTypeAlias"] !== null) {
            $this->InstanceTypeAlias = $param["InstanceTypeAlias"];
        }

        if (array_key_exists("RDMAConfig",$param) and $param["RDMAConfig"] !== null) {
            $this->RDMAConfig = new RDMAConfig();
            $this->RDMAConfig->deserialize($param["RDMAConfig"]);
        }
    }
}
