<?php
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
namespace TencentCloud\Tts\V20190823\Models;
use TencentCloud\Common\AbstractModel;

/**
 * TextToVoice返回参数结构体
 *
 * @method string getAudio() 获取base64编码的wav/mp3音频数据
 * @method void setAudio(string $Audio) 设置base64编码的wav/mp3音频数据
 * @method string getSessionId() 获取一次请求对应一个SessionId
 * @method void setSessionId(string $SessionId) 设置一次请求对应一个SessionId
 * @method array getSubtitles() 获取时间戳信息，若未开启时间戳，则返回空数组。
 * @method void setSubtitles(array $Subtitles) 设置时间戳信息，若未开启时间戳，则返回空数组。
 * @method string getRequestId() 获取唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
 * @method void setRequestId(string $RequestId) 设置唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
 */
class TextToVoiceResponse extends AbstractModel
{
    /**
     * @var string base64编码的wav/mp3音频数据
     */
    public $Audio;

    /**
     * @var string 一次请求对应一个SessionId
     */
    public $SessionId;

    /**
     * @var array 时间戳信息，若未开启时间戳，则返回空数组。
     */
    public $Subtitles;

    /**
     * @var string 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public $RequestId;

    /**
     * @param string $Audio base64编码的wav/mp3音频数据
     * @param string $SessionId 一次请求对应一个SessionId
     * @param array $Subtitles 时间戳信息，若未开启时间戳，则返回空数组。
     * @param string $RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    function __construct()
    {

    }

    /**
     * For internal only. DO NOT USE IT.
     */
    public function deserialize($param)
    {
        if ($param === null) {
            return;
        }
        if (array_key_exists("Audio",$param) and $param["Audio"] !== null) {
            $this->Audio = $param["Audio"];
        }

        if (array_key_exists("SessionId",$param) and $param["SessionId"] !== null) {
            $this->SessionId = $param["SessionId"];
        }

        if (array_key_exists("Subtitles",$param) and $param["Subtitles"] !== null) {
            $this->Subtitles = [];
            foreach ($param["Subtitles"] as $key => $value){
                $obj = new Subtitle();
                $obj->deserialize($value);
                array_push($this->Subtitles, $obj);
            }
        }

        if (array_key_exists("RequestId",$param) and $param["RequestId"] !== null) {
            $this->RequestId = $param["RequestId"];
        }
    }
}
