<?php
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
namespace TencentCloud\Bsca\V20210811\Models;
use TencentCloud\Common\AbstractModel;

/**
 * DescribeKBComponentVulnerability返回参数结构体
 *
 * @method array getVulnerabilityList() 获取漏洞信息列表
注意：此字段可能返回 null，表示取不到有效值。
 * @method void setVulnerabilityList(array $VulnerabilityList) 设置漏洞信息列表
注意：此字段可能返回 null，表示取不到有效值。
 * @method PURL getPURL() 获取组件purl
 * @method void setPURL(PURL $PURL) 设置组件purl
 * @method string getRecommendedVersion() 获取推荐版本，最小无高危/严重漏洞的版本。无法升级到安全版本时的备选方案。
 * @method void setRecommendedVersion(string $RecommendedVersion) 设置推荐版本，最小无高危/严重漏洞的版本。无法升级到安全版本时的备选方案。
 * @method string getSecureVersion() 获取安全版本（首选），最小无漏洞的版本。当无法升级到安全版本时可考虑使用推荐版本。
 * @method void setSecureVersion(string $SecureVersion) 设置安全版本（首选），最小无漏洞的版本。当无法升级到安全版本时可考虑使用推荐版本。
 * @method string getRequestId() 获取唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
 * @method void setRequestId(string $RequestId) 设置唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
 */
class DescribeKBComponentVulnerabilityResponse extends AbstractModel
{
    /**
     * @var array 漏洞信息列表
注意：此字段可能返回 null，表示取不到有效值。
     */
    public $VulnerabilityList;

    /**
     * @var PURL 组件purl
     */
    public $PURL;

    /**
     * @var string 推荐版本，最小无高危/严重漏洞的版本。无法升级到安全版本时的备选方案。
     */
    public $RecommendedVersion;

    /**
     * @var string 安全版本（首选），最小无漏洞的版本。当无法升级到安全版本时可考虑使用推荐版本。
     */
    public $SecureVersion;

    /**
     * @var string 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public $RequestId;

    /**
     * @param array $VulnerabilityList 漏洞信息列表
注意：此字段可能返回 null，表示取不到有效值。
     * @param PURL $PURL 组件purl
     * @param string $RecommendedVersion 推荐版本，最小无高危/严重漏洞的版本。无法升级到安全版本时的备选方案。
     * @param string $SecureVersion 安全版本（首选），最小无漏洞的版本。当无法升级到安全版本时可考虑使用推荐版本。
     * @param string $RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    function __construct()
    {

    }

    /**
     * For internal only. DO NOT USE IT.
     */
    public function deserialize($param)
    {
        if ($param === null) {
            return;
        }
        if (array_key_exists("VulnerabilityList",$param) and $param["VulnerabilityList"] !== null) {
            $this->VulnerabilityList = [];
            foreach ($param["VulnerabilityList"] as $key => $value){
                $obj = new ComponentVulnerabilityUnion();
                $obj->deserialize($value);
                array_push($this->VulnerabilityList, $obj);
            }
        }

        if (array_key_exists("PURL",$param) and $param["PURL"] !== null) {
            $this->PURL = new PURL();
            $this->PURL->deserialize($param["PURL"]);
        }

        if (array_key_exists("RecommendedVersion",$param) and $param["RecommendedVersion"] !== null) {
            $this->RecommendedVersion = $param["RecommendedVersion"];
        }

        if (array_key_exists("SecureVersion",$param) and $param["SecureVersion"] !== null) {
            $this->SecureVersion = $param["SecureVersion"];
        }

        if (array_key_exists("RequestId",$param) and $param["RequestId"] !== null) {
            $this->RequestId = $param["RequestId"];
        }
    }
}
